@@ -89,6 +89,7 @@ typedef enum mpd_TagItems
 	MPD_TAG_ITEM_COMMENT,
 	MPD_TAG_ITEM_DISC,
 	MPD_TAG_ITEM_FILENAME,
+    MPD_TAG_ITEM_ALBUM_ARTIST,
 	MPD_TAG_ITEM_ANY,
 	MPD_TAG_NUM_OF_ITEM_TYPES
 } mpd_TagItems;
@@ -282,6 +283,8 @@ typedef struct _mpd_Song {
 	/* Comment */
 	char *comment;
 
+    /* AlbumArtist */
+    char *albumartist;
 	/* length of song in seconds, check that it is not MPD_SONG_NO_TIME  */
 	int time;
 	/* if plchanges/playlistinfo/playlistid used, is the position of the
@@ -310,7 +313,7 @@ void mpd_freeSong(mpd_Song * song);
 /* mpd_songDup
  * works like strDup, but for a mpd_Song
  */
-mpd_Song * mpd_songDup(mpd_Song * song);
+mpd_Song * mpd_songDup(const mpd_Song * song);
 
 /* DIRECTORY STUFF */
 
@@ -519,7 +522,7 @@ void mpd_sendVolumeCommand(mpd_Connection * connection, int volumeChange);
 
 void mpd_sendCrossfadeCommand(mpd_Connection * connection, int seconds);
 
-void mpd_sendUpdateCommand(mpd_Connection * connection, char * path);
+void mpd_sendUpdateCommand(mpd_Connection * connection,const char * path);
 
 /* returns the update job id, call this after a update command*/
 int mpd_getUpdateId(mpd_Connection * connection);
@@ -597,7 +600,7 @@ char *mpd_getNextTagType(mpd_Connection * connection);
  * List the content, with full metadata, of a stored playlist.
  *
  */
-void mpd_sendListPlaylistInfoCommand(mpd_Connection *connection, char *path);
+void mpd_sendListPlaylistInfoCommand(mpd_Connection *connection,const char *path);
 
 /**
  * @param connection a MpdConnection
@@ -606,7 +609,7 @@ void mpd_sendListPlaylistInfoCommand(mpd_Connection *connection, char *path);
  * List the content of a stored playlist.
  *
  */
-void mpd_sendListPlaylistCommand(mpd_Connection *connection, char *path);
+void mpd_sendListPlaylistCommand(mpd_Connection *connection,const char *path);
 
 /**
  * @param connection a #mpd_Connection
@@ -656,22 +659,27 @@ void mpd_startPlaylistSearch(mpd_Connection *connection, int exact);
 
 void mpd_startStatsSearch(mpd_Connection *connection);
 
-void mpd_sendPlaylistClearCommand(mpd_Connection *connection, char *path);
+void mpd_sendPlaylistClearCommand(mpd_Connection *connection,const char *path);
 
 void mpd_sendPlaylistAddCommand(mpd_Connection *connection,
-                                char *playlist, char *path);
+                                const char *playlist,const char *path);
 
 void mpd_sendPlaylistMoveCommand(mpd_Connection *connection,
-                                 char *playlist, int from, int to);
+                                 const char *playlist, int from, int to);
 
 void mpd_sendPlaylistDeleteCommand(mpd_Connection *connection,
-                                   char *playlist, int pos);
+                                   const char *playlist, int pos);
 
 void mpd_sendClearErrorCommand(mpd_Connection * connection);
 
 void mpd_sendGetEventsCommand(mpd_Connection *connection);
 char * mpd_getNextEvent(mpd_Connection *connection);
 void mpd_sendListPlaylistsCommand(mpd_Connection * connection);
+/* Stickers*/
+char * mpd_getNextSticker (mpd_Connection * connection);
+
+void mpd_sendSetSongSticker(mpd_Connection *connection, const char *song, const char *sticker, const char *value);
+void  mpd_sendGetSongSticker(mpd_Connection *connection, const char *song, const char *sticker);
 
 #ifdef __cplusplus
 }
